@@ -1,27 +1,7 @@
-/* PipeWire
- *
- * Copyright © 2021 Wim Taymans <wim.taymans@gmail.com>
- * Copyright © 2021 Sanchayan Maity <sanchayan@asymptotic.io>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice (including the next
- * paragraph) shall be included in all copies or substantial portions of the
- * Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
- * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
- */
+/* PipeWire */
+/* SPDX-FileCopyrightText: Copyright © 2021 Wim Taymans <wim.taymans@gmail.com> */
+/* SPDX-FileCopyrightText: Copyright © 2021 Sanchayan Maity <sanchayan@asymptotic.io> */
+/* SPDX-License-Identifier: MIT */
 
 #include <limits.h>
 #include <sys/stat.h>
@@ -74,7 +54,6 @@
  * context.modules = [
  *  {   name = libpipewire-module-roc-sink
  *      args = {
- *          local.ip = 0.0.0.0
  *          fec.code = disable
  *          remote.ip = 192.168.0.244
  *          remote.source.port = 10001
@@ -370,13 +349,12 @@ static int roc_sink_setup(struct module_roc_sink_data *data)
 static const struct spa_dict_item module_roc_sink_info[] = {
 	{ PW_KEY_MODULE_AUTHOR, "Sanchayan Maity <sanchayan@asymptotic.io>" },
 	{ PW_KEY_MODULE_DESCRIPTION, "roc sink" },
-	{ PW_KEY_MODULE_USAGE,	"sink.name=<name for the sink> "
-				"local.ip=<local sender ip> "
-				"fec.code=<empty>|disable|rs8m|ldpc "
+	{ PW_KEY_MODULE_USAGE,	"( sink.name=<name for the sink> ) "
+				"( fec.code=<empty>|disable|rs8m|ldpc ) "
 				"remote.ip=<remote receiver ip> "
-				"remote.source.port=<remote receiver port for source packets> "
-				"remote.repair.port=<remote receiver port for repair packets> "
-				"sink.props= { key=val ... } " },
+				"( remote.source.port=<remote receiver port for source packets> ) "
+				"( remote.repair.port=<remote receiver port for repair packets> ) "
+				"( sink.props= { key=val ... } ) " },
 	{ PW_KEY_MODULE_VERSION, PACKAGE_VERSION },
 };
 
